@@ -598,14 +598,14 @@ void Uic::createFormImpl( const TQDomElement &e )
 		    receiver = "self." + receiver;
 
 		out << indent << "self.connect(" << sender
-		    << ",SIGNAL(\"" << signal << "\")," << receiver;
+		    << ",TQ_SIGNAL(\"" << signal << "\")," << receiver;
 
-		// Normally we never use the SLOT() macro in case the
+		// Normally we never use the TQ_SLOT() macro in case the
 		// connection is to a method of a Python custom widget.  The
 		// exception is if the receiver is a TQAxWidget where it must be
 		// used because the slots are dynamic.
 		if (isaxwidget)
-		    out << ",SLOT(\"" << slot << "\")";
+		    out << ",TQ_SLOT(\"" << slot << "\")";
 		else
 		{
 		    TQString mname = slot.left(slot.find('('));
